@@ -117,7 +117,7 @@ def _get_source(source_file: pathlib.Path) -> str:
 
     resolved_file_path = source_file.resolve()
     with contextlib.closing(docutils.io.FileInput(source_path=resolved_file_path)) as input_file:
-        return t.cast(str, input_file.read())
+        return input_file.read()
 
 
 def _replace_ignored_substitutions(source: str, ignore_substitutions: t.List[str]) -> str:
@@ -809,7 +809,7 @@ class CodeBlockChecker:
         :return: :py:obj:`None` if no issues were found else a tuple of the stderr and temp-file
             name
         """
-        get_encoding = lambda: locale.getpreferredencoding() or sys.getdefaultencoding()
+        encoding = locale.getpreferredencoding() or sys.getdefaultencoding()
 
         source_origin_path = self.source_origin
         if isinstance(source_origin_path, str):
@@ -833,7 +833,7 @@ class CodeBlockChecker:
             )
 
             if result.returncode != 0:
-                return (result.stderr.decode(get_encoding()), temporary_file_path)
+                return (result.stderr.decode(encoding), temporary_file_path)
             return None
         finally:
             temporary_file_path.unlink()
